Translator component toolkit (TCT) — Translator Component Toolkit 0.1 documentation

# Translator component toolkit (TCT)

## What is TCT?

Translator Component Toolkit is a python library that allowing users to explore and use KGs in the Translator ecosystems. Users can check out the key functions here: https://gloriachin.github.io/Translator_component_toolkit/

## Key features for TCT

Allowing users to select APIs, predicates according to the user’s intention.
Parallel and fast quering of the selected APIs.
Providing reproducible results by setting contraints.
Allowing testing whether a user defined API follows a TRAPI standard or not.
Faciliting to explore knowledge graphs from both Translator ecosystem and user defined APIs.
Connecting large language models to convert user’s questions into TRAPI queries.

## How to use TCT

### Install Requirments

To install TCT as a python library, first clone this repository, and then run `pip install -e .` from this folder.

### Please follow the example notebooks (three utilities) below to explore the Translator APIs.

#### Connection finder

Example notebook for ConnectionFinder

#### Path finder

Example notebook for PathFinder

#### Network finder

Example notebook for NetworkFinder

#### Translate users’ questions into TRAPI queries

Example notebook for translating users’ questions into TRAPI queries can be found here.

#### Connecting to a user’s API

API should be developed following the standard from TRAPI.
An example notebook for add a user’s API can be found here.
Warning: It does not work if no user’ API is established

## Key Translator components

Connecting to key Translator components can be found here

## Contributing

TCT is a tool that helps to explore knowledge graphs developed in the Biomedical Data Translator Consortium. Consortium members and external contributors are encouraged to submit issues and pull requests.

## Contact info

Guangrong Qin, guangrong.qin@isbscience.org